@@ -17,10 +17,6 @@
         <source>About</source>
         <translation>Относно</translation>
     </message>
-    <message>
-        <source>Check For Updates</source>
-        <translation>Проверка за актуализации</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>ОК</translation>
@@ -914,18 +910,6 @@ failed to upload.</source>
         <source>Abort</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Saving</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>File save failed</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Index progress request error %1</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>FileBrowserSearchModel</name>
@@ -1105,6 +1089,14 @@ failed to upload.</source>
         <source>&amp;Generate %1 Upload Link</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Are you sure you want to delete &quot;%1&quot; ?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete those files ?</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FinderSyncHost</name>
@@ -1583,11 +1575,15 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Confirm to bulk delete files in library &quot;%1&quot; ?</source>
+        <source>Deleted &quot;%1&quot; and %2 more files.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Deleted &quot;%1&quot; and %2 more files.</source>
+        <source>Too many files in library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -2244,6 +2240,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Waiting for confirmation to delete files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Too many files in library</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2564,6 +2564,18 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Set Sync Internval For Library &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Show sync errors</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Discard sync errors</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Ignore sync errors from this library</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReposTab</name>
@@ -2988,10 +3000,6 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Enable Explorer Extension</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Check for updates automatically</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Do not verify server certificate in HTTPS syncing</source>
         <translation type="unfinished"/>
@@ -3053,7 +3061,7 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Confirm before bulk deleting files more than</source>
+        <source>Confirm before deleting files more than</source>
         <translation type="unfinished"/>
     </message>
 </context>
