@@ -12,6 +12,7 @@
 #include "rpc/rpc-client.h"
 #include "rpc/sync-error.h"
 #include "ui/tray-icon.h"
+#include "sync-error-service.h"
 
 #include "message-poller.h"
 #if defined(_MSC_VER)
@@ -139,6 +140,21 @@ void MessagePoller::processNotification(const SyncNotification& notification)
         QString title = QString::fromUtf8(json_string_value(json_object_get(object, "repo_name")));
         QString path = QString::fromUtf8(json_string_value(json_object_get(object, "path")));
         int err_id = json_integer_value(json_object_get(object, "err_id"));
+
+        switch (err_id) {
+        case SYNC_ERROR_ID_FILE_LOCKED_BY_APP:
+        case SYNC_ERROR_ID_INDEX_ERROR:
+        case SYNC_ERROR_ID_PATH_END_SPACE_PERIOD:
+        case SYNC_ERROR_ID_PATH_INVALID_CHARACTER:
+        case SYNC_ERROR_ID_UPDATE_TO_READ_ONLY_REPO:
+        case SYNC_ERROR_ID_REMOVE_UNCOMMITTED_FOLDER:
+#if !defined(Q_OS_WIN32)
+        case SYNC_ERROR_ID_INVALID_PATH_ON_WINDOWS:
+#endif
+            LastSyncError::instance()->flagRepoSyncError(repo_id, err_id);
+            break;
+        }
+
         QString msg;
         switch (err_id) {
         case SYNC_ERROR_ID_FILE_LOCKED_BY_APP:
@@ -188,6 +204,9 @@ void MessagePoller::processNotification(const SyncNotification& notification)
         case SYNC_ERROR_ID_DEL_CONFIRMATION_PENDING:
             msg = tr("Waiting for confirmation to delete files");
             break;
+        case SYNC_ERROR_ID_TOO_MANY_FILES:
+            msg = tr("Too many files in library");
+            break;
         default:
             qWarning("Unknown sync error id %d", err_id);
             json_decref(object);
@@ -224,10 +243,10 @@ void MessagePoller::processNotification(const SyncNotification& notification)
                       .arg(match.captured(1)).arg(match.captured(2));
         }
 
-        QString info = tr("Confirm to bulk delete files in library \"%1\" ?")
+        QString info = tr("Do you want to delete files in library \"%1\" ?")
                           .arg(doc["repo_name"].toString().trimmed());
 
-        if (seafApplet->bulkDeletingMessageBox(text, info)) {
+        if (seafApplet->deletingConfirmationBox(text, info)) {
             rpc_client_->addDelConfirmation(doc["confirmation_id"].toString(), false);
         } else {
             rpc_client_->addDelConfirmation(doc["confirmation_id"].toString(), true);
