@@ -49,11 +49,6 @@
     #include "finder-sync/finder-sync-listener.h"
 #endif
 
-#ifdef HAVE_SPARKLE_SUPPORT
-#include "auto-update-service.h"
-#endif
-
-
 #if defined(Q_OS_MAC)
 #include "utils/utils-mac.h"
 #endif
@@ -230,11 +225,6 @@ SeafileApplet::~SeafileApplet()
         delete main_win_;
 #if defined(Q_OS_WIN32)
     SeafileExtensionHandler::instance()->stop();
-
-#ifdef HAVE_SPARKLE_SUPPORT
-    AutoUpdateService::instance()->stop();
-#endif
-
 #endif
 }
 
@@ -404,12 +394,6 @@ void SeafileApplet::onDaemonStarted()
 #elif defined(HAVE_FINDER_SYNC_SUPPORT)
     finderSyncListenerStart();
 #endif
-
-#ifdef HAVE_SPARKLE_SUPPORT
-    if (AutoUpdateService::instance()->shouldSupportAutoUpdate()) {
-        AutoUpdateService::instance()->start();
-    }
-#endif
 }
 
 void SeafileApplet::checkInitVDrive()
@@ -535,6 +519,7 @@ void SeafileApplet::warningBox(const QString& msg, QWidget *parent)
     box.setWindowTitle(getBrand());
     box.setIcon(QMessageBox::Warning);
     box.addButton(tr("OK"), QMessageBox::YesRole);
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
 
     if (!parent && main_win_) {
@@ -553,6 +538,7 @@ void SeafileApplet::messageBox(const QString& msg, QWidget *parent)
     if (!parent) {
         main_win_->showWindow();
     }
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
     qDebug("%s", msg.toUtf8().data());
 }
@@ -566,6 +552,7 @@ bool SeafileApplet::yesOrNoBox(const QString& msg, QWidget *parent, bool default
     QPushButton *yes_btn = box.addButton(tr("Yes"), QMessageBox::YesRole);
     QPushButton *no_btn = box.addButton(tr("No"), QMessageBox::NoRole);
     box.setDefaultButton(default_val ? yes_btn: no_btn);
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
 
     return box.clickedButton() == yes_btn;
@@ -580,6 +567,7 @@ bool SeafileApplet::yesOrCancelBox(const QString& msg, QWidget *parent, bool def
     QPushButton *yes_btn = box.addButton(tr("Yes"), QMessageBox::YesRole);
     QPushButton *cancel_btn = box.addButton(tr("Cancel"), QMessageBox::RejectRole);
     box.setDefaultButton(default_yes ? yes_btn: cancel_btn);
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
 
     return box.clickedButton() == yes_btn;
@@ -596,6 +584,7 @@ SeafileApplet::yesNoCancelBox(const QString& msg, QWidget *parent, QMessageBox::
     QPushButton *no_btn = box.addButton(tr("No"), QMessageBox::NoRole);
     box.addButton(tr("Cancel"), QMessageBox::RejectRole);
     box.setDefaultButton(default_btn);
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
 
     QAbstractButton *btn = box.clickedButton();
@@ -624,10 +613,11 @@ bool SeafileApplet::detailedYesOrNoBox(const QString& msg, const QString& detail
     QGridLayout* layout = (QGridLayout*)msgBox.layout();
     layout->addItem(horizontalSpacer, layout->rowCount(), 0, 1, layout->columnCount());
     msgBox.setDefaultButton(default_val ? QMessageBox::Yes : QMessageBox::No);
+    msgBox.setFocusPolicy(Qt::ClickFocus);
     return msgBox.exec() == QMessageBox::Yes;
 }
 
-bool SeafileApplet::bulkDeletingMessageBox(const QString& text, const QString& info)
+bool SeafileApplet::deletingConfirmationBox(const QString& text, const QString& info)
 {
     QMessageBox box(main_win_);
 
@@ -643,6 +633,7 @@ bool SeafileApplet::bulkDeletingMessageBox(const QString& text, const QString& i
     auto settingsButton = box.addButton(tr("Settings"), QMessageBox::NoRole);
     box.setDefaultButton(noButton);
 
+    box.setFocusPolicy(Qt::ClickFocus);
     box.exec();
 
     if (box.clickedButton() == yesButton) {
